@@ -8,9 +8,12 @@ use overload
     '<<' => \&append,
     '""' => \&as_string;
 
+
+use JSON::Syck;
+
 __PACKAGE__->mk_accessors qw(statements);
 
-our $VERSION = '0.0.4';
+our $VERSION = '0.0.5';
 
 sub new {
     my $class = shift;
@@ -43,6 +46,28 @@ sub object {
     return $self;
 }
 
+sub var {
+    my ($self, $var, $value) = @_;
+    my $s = "";
+    if (defined $value) {
+        if (ref($value) eq 'ARRAY'
+                || ref($value) eq 'HASH'
+                || !ref($value) ) {
+            $s = "var $var = " . JSON::Syck::Dump($value) . ";"
+        }
+        elsif (ref($value) eq 'CODE') {
+            $s = "var $var = " . $self->function($value);
+        }
+        elsif (ref($value) =~ '^JavaScript::Writer') {
+            $s = "var $var = " . $value->as_string();
+        }
+    }
+    else {
+        $s = "var $var;";
+    }
+    $self->append($s)
+}
+
 use JavaScript::Writer::Function;
 
 sub function {
@@ -52,8 +77,6 @@ sub function {
     return $jsf;
 }
 
-use JSON::Syck;
-
 sub as_string {
     my ($self) = @_;
     my $ret = "";
@@ -143,6 +166,12 @@ perl's native form, you don't need to use L<JSON> module to serialized
 it first.  (Unless, of course, that's your purpose: to get a JSON
 string in JavaScript.)
 
+
+=item var( $name, [ $value ] )
+
+Declare a value named $name with a optional default value $value.
+$value could be an arrayref, hashref, or scalar.
+
 =item object( $object )
 
 Give the object name for next function call. The preferred usage is:
